pub struct AstCapabilityWithCodeIndex { /* private fields */ }Expand description
AST capability registered with access to the shared code-index state.
Most AST builtins are stateless, but ast.dry_run can preview
rename_symbol plan ops only when it can delegate to the typed
symbol graph owned by code_index.
Implementations
Sourceimpl AstCapabilityWithCodeIndex
impl AstCapabilityWithCodeIndex
Sourcepub fn new(code_index: SharedIndex) -> Self
pub fn new(code_index: SharedIndex) -> Self
Build an AST capability that can delegate dry-run rename previews to the supplied code-index state.