pub fn commit_staged(
session_id: &str,
paths: &[String],
) -> Result<CommitResult, HostlibError>Expand description
Commit staged changes for all paths or for a filtered path list.
pub fn commit_staged(
session_id: &str,
paths: &[String],
) -> Result<CommitResult, HostlibError>Commit staged changes for all paths or for a filtered path list.