pub enum HostConditionStatus {
Observed,
Unavailable,
NotObservable,
}Expand description
The three observability states. Quiet is an Observed value of zero.
Variants
Observed
A real reading was obtained.
The environment should expose an answer, but the read failed.
NotObservable
This environment cannot expose an answer to the question.