pub fn current_spawner() -> Arc<dyn ProcessSpawner> ⓘExpand description
Return the currently installed spawner for this thread, falling back to the default real spawner.
pub fn current_spawner() -> Arc<dyn ProcessSpawner> ⓘReturn the currently installed spawner for this thread, falling back to the default real spawner.