Module real

Module real 

Production ProcessSpawner implementation backed by std::process::Command + harn_vm::process_sandbox.

Structs

RealSpawner
Spawner that produces real OS processes via std::process::Command.

Functions

default_spawner
Returns the singleton real spawner used as the default.
replace_current_process
Replace the current Unix process through the same prepared-command path as normal hostlib spawns. A successful call never returns.