pub fn replace_current_process(
spec: SpawnSpec,
) -> Result<Infallible, ProcessError>Expand description
Replace the current Unix process through the same prepared-command path as normal hostlib spawns. A successful call never returns.
pub fn replace_current_process(
spec: SpawnSpec,
) -> Result<Infallible, ProcessError>Replace the current Unix process through the same prepared-command path as normal hostlib spawns. A successful call never returns.