pub fn scan_project(root: &Path, opts: ScanProjectOptions) -> ScanResultExpand description
Run a full scan of root, persist a snapshot, and return the result.
pub fn scan_project(root: &Path, opts: ScanProjectOptions) -> ScanResultRun a full scan of root, persist a snapshot, and return the result.