pub fn configure_session_root(session_id: &str, root: &Path)Expand description
Remember the workspace root associated with a live session.
ACP calls this when a prompt starts so Harn code can call
hostlib_fs_set_mode({session_id, mode}) without also passing a root.