pub trait ProcessKiller: Send + Sync { // Required method fn kill(&self); }
Kill side of a ProcessHandle. Cloneable via Arc so cancellation works after the waiter thread has taken ownership of the handle itself.
ProcessHandle
Arc
Send SIGKILL to the process (and its process group, when applicable).